ReactiveStates class

A widget that conditionally builds based on multiple reactive state updates.

This widget listens to a set of StateBuilders (typically produced by ValueState, InitedState or VoidState) and rebuilds when any of them is updated via refreshWith() or refreshUpdate().

The most recently updated state will be passed to the matching builder, ensuring that only the relevant state widget is rebuilt.

This is ideal when you have multiple reactive states but want a unified reactive handler to build different widgets depending on which state was updated.


Example:

final name = InitedState("Felipe");
final age = InitedState(23);

ReactiveStates({
  name.on((value) => Text('Name: $value')),
  age.on((value) => Text('Age: $value')),
});

name.refreshWith("Kaian"); // Only the name widget will rebuild.

If no known state was updated, defaultCase is rendered (if provided).

Inheritance

Constructors

ReactiveStates(Set<StateBuilder> stateBuilders, {Key? key, Widget defaultCase()?})
Creates a ReactiveStates widget with a set of reactive builders.
const

Properties

defaultCase Widget Function()?
A fallback widget builder to render if no reactive match is found.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateBuilders Set<StateBuilder>
A set of builders associated with unique reactive states.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ReactiveStates>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited